PCR - Python Cryptography Experimentation Kit
=============================================

This package provides pure python implementations of various
cryptographic algorithms and protocols. Since doing cryptography
in Python is inherently slow, it is meant as a study aid and
experimentation kit.

For more information, see `github.com/sfstpala/pcr <http://github.com/sfstpala/pcr/>`_.
